students = {
    "23MSS001": "AAKASH S",
    "23MSS002": "AARTHI B",
    "23MSS003": "ABIRAMI S",
    "23MSS004": "AJAY S P",
    "23MSS005": "AJITH KUMAR R",
    "23MSS006": "ANUSHRI R",
    "23MSS007": "ARAVIND NIKESH R",
    "23MSS008": "ASWATHNIVASH A",
    "23MSS009": "DEEKSHITH S",
    "23MSS010": "DHANYA SHREE S",
    "23MSS011": "DIVYABALA D",
    "23MSS012": "GAYATHRI J",
    "23MSS013": "GOWSHIGA I",
    "23MSS014": "GOWTHAMRAJ R",
    "23MSS015": "GURUNATHAN K",
    "23MSS016": "INIYAN M",
    "23MSS017": "JACOB P ASHWANTH RISHI",
    "23MSS018": "JANAGIRAMAN S B",
    "23MSS019": "JANANI K",
    "23MSS020": "KAVINRAGHUL V",
    "23MSS021": "KAVYA V",
    "23MSS022": "KEERTHIVASAN R",
    "23MSS023": "KIRITHIK S",
    "23MSS024": "KISHORE R",
    "23MSS025": "KOVARTHINI B",
    "23MSS026": "LOKAJITH KRISHNA P T",
    "23MSS027": "MANOGARAN M",
    "23MSS028": "MUKHILA J",
    "23MSS029": "NAVEEN PRASAD T",
    "23MSS030": "NIKILAN U",
    "23MSS031": "NIVETHAN N",
    "23MSS032": "PRABAKARAN P",
    "23MSS033": "PRANIKA SHRI E M",
    "23MSS034": "RAGHAVEE G",
    "23MSS035": "RAIHANA SABOORA A",
    "23MSS036": "RANJANAA S",
    "23MSS037": "RESHMAA R",
    "23MSS038": "RITHIKA P S",
    "23MSS039": "RITIKA S",
    "23MSS040": "RUBESH RAJH V S",
    "23MSS041": "SAI NANDHANA S",
    "23MSS042": "SAMIKSHA M",
    "23MSS043": "SANJAY R",
    "23MSS044": "SANJAY SURIYA KANNAN",
    "23MSS045": "SARANYA G R",
    "23MSS046": "SASHTIKA MUTHU SIVASALAMOORTHY",
    "23MSS047": "SHALINI M",
    "23MSS048": "SHIVANI S S",
    "23MSS049": "SHREYA M",
    "23MSS050": "SREENITHI B G",
    "23MSS051": "SRI DARSHAN C S",
    "23MSS052": "SRI KABILAN R",
    "23MSS053": "SRIRAM S S",
    "23MSS054": "THARUN M S S",
    "23MSS055": "VAISHNAVAPRIYA R G",
    "23MSS056": "VARSHA S",
    "23MSS057": "VISWANTH R",
    "23MSS058": "YASHVANTH RAAM R",
    "23MSS059": "YOGA SRI S K",
}

def get_student_name(student_id):
    """Returns the name of the student given their ID"""
    return students.get(student_id, "Unknown Student")
